@@ -1049,52 +1049,49 @@ curl_easy_setopt_ccsid(CURL * curl, CURLoption tag, ...)
   case CURLOPT_COOKIEFILE:
   case CURLOPT_COOKIEJAR:
   case CURLOPT_COOKIELIST:
+  case CURLOPT_CRLFILE:
   case CURLOPT_CUSTOMREQUEST:
   case CURLOPT_EGDSOCKET:
   case CURLOPT_ENCODING:
-  case CURLOPT_FTPPORT:
   case CURLOPT_FTP_ACCOUNT:
   case CURLOPT_FTP_ALTERNATIVE_TO_USER:
+  case CURLOPT_FTPPORT:
   case CURLOPT_INTERFACE:
+  case CURLOPT_ISSUERCERT:
   case CURLOPT_KEYPASSWD:
   case CURLOPT_KRBLEVEL:
+  case CURLOPT_MAIL_FROM:
   case CURLOPT_NETRC_FILE:
+  case CURLOPT_NOPROXY:
+  case CURLOPT_PASSWORD:
   case CURLOPT_PROXY:
+  case CURLOPT_PROXYPASSWORD:
+  case CURLOPT_PROXYUSERNAME:
   case CURLOPT_PROXYUSERPWD:
   case CURLOPT_RANDOM_FILE:
   case CURLOPT_RANGE:
   case CURLOPT_REFERER:
+  case CURLOPT_RTSP_SESSION_ID:
+  case CURLOPT_RTSP_STREAM_URI:
+  case CURLOPT_RTSP_TRANSPORT:
+  case CURLOPT_SOCKS5_GSSAPI_SERVICE:
+  case CURLOPT_SSH_HOST_PUBLIC_KEY_MD5:
+  case CURLOPT_SSH_KNOWNHOSTS:
   case CURLOPT_SSH_PRIVATE_KEYFILE:
   case CURLOPT_SSH_PUBLIC_KEYFILE:
   case CURLOPT_SSLCERT:
   case CURLOPT_SSLCERTTYPE:
+  case CURLOPT_SSL_CIPHER_LIST:
   case CURLOPT_SSLENGINE:
   case CURLOPT_SSLKEY:
   case CURLOPT_SSLKEYTYPE:
-  case CURLOPT_SSL_CIPHER_LIST:
-  case CURLOPT_URL:
-  case CURLOPT_USERAGENT:
-  case CURLOPT_USERPWD:
-  case CURLOPT_SSH_HOST_PUBLIC_KEY_MD5:
-  case CURLOPT_CRLFILE:
-  case CURLOPT_ISSUERCERT:
-  case CURLOPT_USERNAME:
-  case CURLOPT_PASSWORD:
-  case CURLOPT_PROXYUSERNAME:
-  case CURLOPT_PROXYPASSWORD:
-  case CURLOPT_NOPROXY:
-  case CURLOPT_RTSP_SESSION_ID:
-  case CURLOPT_RTSP_STREAM_URI:
-  case CURLOPT_RTSP_TRANSPORT:
-  /* SSH2 not (yet) implemented on OS400. */
-  /* case CURLOPT_SSH_KNOWNHOSTS: */
-  case CURLOPT_SOCKS5_GSSAPI_SERVICE:
-  case CURLOPT_MAIL_FROM:
-#ifdef USE_TLS_SRP
-  case CURLOPT_TLSAUTH_USERNAME:
   case CURLOPT_TLSAUTH_PASSWORD:
   case CURLOPT_TLSAUTH_TYPE:
-#endif
+  case CURLOPT_TLSAUTH_USERNAME:
+  case CURLOPT_URL:
+  case CURLOPT_USERAGENT:
+  case CURLOPT_USERNAME:
+  case CURLOPT_USERPWD:
     s = va_arg(arg, char *);
     ccsid = va_arg(arg, unsigned int);
 
